# coding=utf-8
#
# This file is part of Hypothesis, which may be found at
# https://github.com/HypothesisWorks/hypothesis/
#
# Most of this work is copyright (C) 2013-2019 David R. MacIver
# (david@drmaciver.com), but it contains contributions by others. See
# CONTRIBUTING.rst for a full list of people who may hold copyright, and
# consult the git log if you need to determine who owns an individual
# contribution.
#
# This Source Code Form is subject to the terms of the Mozilla Public License,
# v. 2.0. If a copy of the MPL was not distributed with this file, You can
# obtain one at https://mozilla.org/MPL/2.0/.
#
# END HEADER

from __future__ import absolute_import, division, print_function

import hypothesis.strategies as st
from hypothesis import given


@given(st.from_type(int))
def test_from_int_is_int(x):
    assert isinstance(x, int)


@given(st.from_type(long))
def test_from_long_is_long(x):
    assert isinstance(x, long)


class OldStyleInitlessClass:
    pass


def test_builds_old_style_initless_class():
    st.builds(OldStyleInitlessClass).example()
